#!/bin/bash

# *****************************************************************
#
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2019. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# *****************************************************************

powerai_restore_var_final() {
    # Restore the original value of a previously-saved variable if this
    # is the final deactivation of a conda environment (i.e. deactivate
    # of the "outermost" environment in an activate stack)
    #
    # Take care to distinguish whether the original variable was
    # set (possibly empty) or unset (indicated by special value "unset").
    local package="$1"
    local orig_var="$2"
    local save_var="POWERAI_${package}_${orig_var}"
    local save_val

    if [ "$CONDA_SHLVL" -eq 1 ]
    then
        # Deactivate script being called at SHLVL=1 implies final deactivation
        eval "save_val=\${${save_var}-xxx}"
        if [ "$save_val" = xxx ]
        then

            # Beware that conda sometimes calls the deactivate script _before_
            # calling activate (e.g. when installing the package in a
            # pre-existing, active environment). If the save variable isn't
            # already set, then avoid restore.
            # Note we must use different strings (e.g. 'xxx' vs 'unset') in our
            # tests for unset to distinguish between save_var actually being
            # unset versus being set to the value that indicates the original
            # variable was unset.
            :
        else
            if [ "$save_val" = unset ]
            then
                eval "unset ${orig_var}"
            else
                eval "export ${orig_var}=${save_val}"
            fi

            eval "unset ${save_var}"
        fi
    fi
}

powerai_restore_var_final caffe CAFFE_BIN
powerai_restore_var_final caffe OMP_NUM_THREADS
